@@ -26,7 +26,7 @@ def lemmatize(words: list) -> list:
     return list(map(lambda token: morph.normal_forms(token)[0], words))
 
 
-def excess_but(words: list, part_of_speech: str) -> list:
+def excess_except(words: list, part_of_speech: str) -> list:
     """
     Excess words except chosen part of speech.
 
@@ -37,17 +37,21 @@ def excess_but(words: list, part_of_speech: str) -> list:
     return list(filter(lambda word: morph.parse(word)[0].tag.POS == part_of_speech, words))
 
 
-def tokenize(doc: str) -> list:
+def tokenize(doc: str, part_of_speech="") -> list:
     """
     Preprocessing of a text document to obtain a list of tokens.
 
     :param doc: some document.
+    :param part_of_speech: part of speech (upper register).
     :return: token list.
     """
 
     tokens = simple_preprocess(doc, min_len=2, max_len=50, deacc=True)
     tokens = remove_stop_words(tokens)
-    return lemmatize(tokens)
+    tokens = lemmatize(tokens)
+    if part_of_speech != "":
+        tokens = excess_except(tokens, part_of_speech)
+    return tokens
 
 
 def strings_similarity(s1: str, s2: str) -> float:
