@@ -1,6 +1,7 @@
 from anytree import AnyNode, PreOrderIter, LevelOrderGroupIter
 from anytree.exporter import DictExporter
 from anytree.importer import DictImporter
+from anytree.search import find_by_attr
 
 importer = DictImporter()
 exporter = DictExporter()
@@ -30,10 +31,7 @@ class SectionsTree:
         """
         self.root = importer.import_(template)
 
-    def get_leaf_sections(self) -> list:
-        return [node for node in PreOrderIter(self.root, filter_=lambda n: hasattr(n, "text"))]
-
-    def get_dict_from_root(self) -> dict:
+    def to_dict(self) -> dict:
         # exclude sections from the result for which there were no matches
         for children in LevelOrderGroupIter(self.root):
             for node in children:
@@ -41,8 +39,19 @@ class SectionsTree:
                     node.parent = None
         return exporter.export(self.root)
 
-    def get_contents(self) -> str:
+    def get_leaf_sections(self, section_name="Техническое задание") -> list:
         """
-        Returns the contents of the sections tree.
+        Returns leaf elements of the whole sections tree (from root). If the parameter section_name is specified,
+        it returns leaf elements that are nested in the section of the same name with section_name.
         """
-        return "".join([node.text for node in self.get_leaf_sections()])
+        search_from_node = find_by_attr(self.root, name="name", value=section_name)
+        if search_from_node:
+            return [node for node in PreOrderIter(search_from_node, filter_=lambda n: hasattr(n, "text"))]
+        return []
+
+    def get_content(self, section_name="Техническое задание") -> str:
+        """
+        Returns the content of the section tree (the totality of all text fields). If the parameter section_name is
+        specified, it returns the content that is inside the section named section_name.
+        """
+        return "".join([node.text for node in self.get_leaf_sections(section_name)])
